==> tntdb_1.3.orig.tar.gz: tntdb-1.3/include/tntdb/sqlite/error.h <==
/*
 * Copyright (C) 2005 Tommi Maekitalo
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * As a special exception, you may use this file as part of a free
 * software library without restriction. Specifically, if other files
 * instantiate templates or use macros or inline functions from this
 * file, or you compile this file and link it with other files to
 * produce an executable, this file does not by itself cause the
 * resulting executable to be covered by the GNU General Public
 * License. This exception does not however invalidate any other
 * reasons why the executable file might be covered by the GNU Library
 * General Public License.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef TNTDB_SQLITE_ERROR_H
#define TNTDB_SQLITE_ERROR_H

#include <tntdb/error.h>
#include <sqlite3.h>
#include <string>

namespace tntdb
{
  namespace sqlite
  {
    class SqliteError : public Error
    {
        const char* function;

      public:
        SqliteError(const char* function, const std::string& msg)
          : Error(std::string(function) + ": " + msg)
          { }
        SqliteError(const char* function, const char* errmsg)
          : Error(std::string(function) + ": " + (errmsg ? errmsg : "unknown error"))
          { }
        SqliteError(const char* function, char* errmsg, bool do_free);

        const char* getFunction() const   { return function; }
    };

    class Execerror : public SqliteError
    {
        int errcode;

      public:
        Execerror(const char* function, sqlite3* db, int _errcode);
        Execerror(const char* function, sqlite3_stmt* stmt, int _errcode);
        Execerror(const char* function, int _errcode, const char* errmsg)
          : SqliteError(function, errmsg),
            errcode(_errcode)
          { }
        Execerror(const char* function, int _errcode, char* errmsg, bool do_free)
          : SqliteError(function, errmsg, do_free),
            errcode(_errcode)
          { }

        int getErrorcode() const
          { return errcode; }
    };
  }
}

#endif // TNTDB_SQLITE_ERROR_H

==> tntdb_1.4.orig.tar.gz: tntdb-1.4/include/tntdb/sqlite/error.h <==
/*
 * Copyright (C) 2005 Tommi Maekitalo
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * As a special exception, you may use this file as part of a free
 * software library without restriction. Specifically, if other files
 * instantiate templates or use macros or inline functions from this
 * file, or you compile this file and link it with other files to
 * produce an executable, this file does not by itself cause the
 * resulting executable to be covered by the GNU General Public
 * License. This exception does not however invalidate any other
 * reasons why the executable file might be covered by the GNU Library
 * General Public License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef TNTDB_SQLITE_ERROR_H
#define TNTDB_SQLITE_ERROR_H

#include <tntdb/error.h>
#include <sqlite3.h>
#include <string>

namespace tntdb
{
  namespace sqlite
  {
    class SqliteError : public Error
    {
        const char* function;

      public:
        SqliteError(const char* function, const std::string& msg)
          : Error(std::string(function) + ": " + msg)
          { }
        SqliteError(const char* function, const char* errmsg)
          : Error(std::string(function) + ": " + (errmsg ? errmsg : "unknown error"))
          { }
        SqliteError(const char* function, char* errmsg, bool do_free);

        const char* getFunction() const { return function; }
    };

    class Execerror : public SqliteError
    {
        int errcode;

      public:
        Execerror(const char* function, sqlite3* db, int _errcode);
        Execerror(const char* function, sqlite3_stmt* stmt, int _errcode);
        Execerror(const char* function, int _errcode, const char* errmsg)
          : SqliteError(function, errmsg),
            errcode(_errcode)
          { }
        Execerror(const char* function, int _errcode, char* errmsg, bool do_free)
          : SqliteError(function, errmsg, do_free),
            errcode(_errcode)
          { }

        int getErrorcode() const { return errcode; }
    };
  }
}

#endif // TNTDB_SQLITE_ERROR_H
